=======
History
=======

0.4.* (2020)
------------------

* Refactory redis cache to json cache
* Support pickle Cache
* Add backend class in function hash

0.2.* (2019)
------------------

* Support Partially Clear Cache with Arguments
* Support Flush Backend Cache
* Cache Redis Client Must Decode Responses

0.1.* (2019)
------------------

* Support Method and Property Cache
* Support cache as a decorator with no arguments.
* Init Project.
